@@ -739,7 +739,25 @@ class DataframeType(BaseType):
         results = np.where(counts > 1, True, False)
         self.value[f"result_{uuid4()}"] = results
         return True in results
-
+        
+    @type_operator(FIELD_DATAFRAME)
+    def is_ordered_set(self, other_value):
+        target = self.replace_prefix(other_value.get("target"))
+        value = other_value.get("comparator")
+        if isinstance(value, list):
+            raise Exception('Comparator must be a single String value')
+            
+        return not (False in self.value.groupby(value).agg(lambda x : list(x))[target].map(lambda x: sorted(x) == x).tolist())
+       
+    @type_operator(FIELD_DATAFRAME)
+    def is_not_ordered_set(self, other_value):
+        target = self.replace_prefix(other_value.get("target"))
+        value = other_value.get("comparator")
+        if isinstance(value, list):
+            raise Exception('Comparator must be a single String value')
+            
+        return False in self.value.groupby(value).agg(lambda x : list(x))[target].map(lambda x: sorted(x) == x).tolist() 
+        
     @type_operator(FIELD_DATAFRAME)
     def is_valid_reference(self, other_value):
         target = self.replace_prefix(other_value.get("target"))
